@@ -1,7 +1,7 @@
 package Text::Table::Any;
 
-our $DATE = '2016-09-03'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-09-06'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 #IFUNBUILT
 # # use 5.010001;
@@ -112,7 +112,7 @@ Text::Table::Any - Generate text table using one of several backends
 
 =head1 VERSION
 
-This document describes version 0.03 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2016-09-03.
+This document describes version 0.04 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2016-09-06.
 
 =head1 SYNOPSIS
 
@@ -140,6 +140,74 @@ The example shown in the SYNOPSIS generates the following table:
 
  +-------+----------+----------+
  | Name  | Rank     | Serial   |
+ +-------+----------+----------+
+ | alice | pvt      | 123456   |
+ | bob   | cpl      | 98765321 |
+ | carol | brig gen | 8745     |
+ +-------+----------+----------+
+
+When using C<Text::Table::Org> backend, the result is something like:
+
+ | Name  | Rank     | Serial   |
+ |-------+----------+----------|
+ | alice | pvt      | 123456   |
+ | bob   | cpl      | 98765321 |
+ | carol | brig gen | 8745     |
+
+When using C<Text::Table::CSV> backend:
+
+ "Name","Rank","Serial"
+ "alice","pvt","123456"
+ "bob","cpl","98765321"
+ "carol","brig gen","8745"
+
+When using C<Text::ANSITable> backend:
+
+ .-------+----------+----------.
+ | Name  | Rank     |   Serial |
+ +-------+----------+----------+
+ | alice | pvt      |   123456 |
+ | bob   | cpl      | 98765321 |
+ | carol | brig gen |     8745 |
+ `-------+----------+----------'
+
+When using C<Text::ASCIITable> backend:
+
+ .-----------------------------.
+ | Name  | Rank     | Serial   |
+ +-------+----------+----------+
+ | alice | pvt      |   123456 |
+ | bob   | cpl      | 98765321 |
+ | carol | brig gen |     8745 |
+ '-------+----------+----------'
+
+When using C<Text::FormatTable> backend:
+
+ Name |Rank    |Serial
+ alice|pvt     |123456
+ bob  |cpl     |98765321
+ carol|brig gen|8745
+
+When using C<Text::MarkdownTable> backend:
+
+ | Name  | Rank     | Serial   |
+ |-------|----------|----------|
+ | alice | pvt      | 123456   |
+ | bob   | cpl      | 98765321 |
+ | carol | brig gen | 8745     |
+
+When using C<Text::Table> backend:
+
+ Name  Rank     Serial
+ alice pvt        123456
+ bob   cpl      98765321
+ carol brig gen     8745
+
+When using C<Text::TabularDisplay> backend:
+
+ +-------+----------+----------+
+ | Name  | Rank     | Serial   |
+ +-------+----------+----------+
  | alice | pvt      | 123456   |
  | bob   | cpl      | 98765321 |
  | carol | brig gen | 8745     |
